@@ -1,5 +1,28 @@
-"pgleissberg" <-
-function(n, k, lower.tail=TRUE, two.tailed=FALSE) {
+.gleissberg.calc <- function (n = 50, k = 48)
+{
+	Gleiss <- matrix(0, n - 2, k + 1)
+	N <- nrow(Gleiss)
+	K <- ncol(Gleiss)
+	Gleiss[,1] <- 2
+	Gleiss[1, 2] <- 4
+	for (n in 2:N) {
+		Gleiss[n, 2] <- 2*Gleiss[n-1, 2] + 2*Gleiss[n-1, 1]
+		for (k in 3:K) {
+			for (n in (k-1):N) {
+				Gleiss[n, k] <- k*Gleiss[n-1, k] + 2*Gleiss[n-1,k-1] + (n-k+2)*Gleiss[n-1, k-2]
+			}
+		}
+	}
+	Gleiss <- Gleiss / gamma(4:51)		# gamma(n + 1) is equivalent to n!
+	# This is the probability, giving any (n, k) pair... but we want a table of right-tailed cumulated probabilities
+	Gleiss <- t(apply(t(Gleiss), 2, cumsum))
+	as.matrix(Gleiss)
+}
+
+.gleissberg.table <- .gleissberg.calc()
+
+pgleissberg <- function (n, k, lower.tail=TRUE, two.tailed=FALSE)
+{
 	# Make sure n and k have same length
 	if (length(n) > length(k)) k <- rep(k, length.out=length(n))
 	if (length(n) < length(k)) n <- rep(n, length.out=length(k))
@@ -32,44 +55,10 @@ function(n, k, lower.tail=TRUE, two.tailed=FALSE) {
 			rescalc[Norm] <- resnorm
 		}
 		if (sum(!Norm) > 0) {
-			# Calculate exact Gleissberg distribution
-			# This is normally loaded from gleissberg.table
-			# but if it fails, it can be recalculated with:
-			"gleissberg.calc" <- function() {
-				n <- 50
-				k <- 48
-				Gleiss <- matrix(0, n - 2, k + 1)
-				N <- nrow(Gleiss)
-				K <- ncol(Gleiss)
-				Gleiss[,1] <- 2
-				Gleiss[1, 2] <- 4
-				for (n in 2:N) {
-					Gleiss[n, 2] <- 2*Gleiss[n-1, 2] + 2*Gleiss[n-1, 1]
-					for (k in 3:K) {
-						for (n in (k-1):N) {
-							Gleiss[n, k] <- k*Gleiss[n-1, k] + 2*Gleiss[n-1,k-1] + (n-k+2)*Gleiss[n-1, k-2]
-						}
-					}
-				}
-				Gleiss <- Gleiss / gamma(4:51)		# gamma(n + 1) is equivalent to n!
-				# This is the probability, giving any (n, k) pair... but we want a table of right-tailed cumulated probabilities
-				Gleiss <- t(apply(t(Gleiss), 2, cumsum))
-				assign(".gleissberg.table", Gleiss, env = .GlobalEnv)	
-				invisible(NULL)
-			}
-			
 			# Determination of Gleissberg probability
 			ng <- ncalc[!Norm]
 			kg <- kcalc[!Norm]
-			if (length(objects(envir=.GlobalEnv, all.names=TRUE, pattern=".gleissberg.table")) == 0) {	# Table not found
-				try(data(gleissberg.table))
-				if (length(objects(envir=.GlobalEnv, all.names=TRUE, pattern=".gleissberg.table")) == 0) {	# Table still not found
-					cat("Creating Gleissberg distribution table...\n\n")
-					if (R.Version()$os == "Win32") {flush.console()}
-					gleissberg.calc()
- 				}
- 			}
-			.gleissberg.table <- as.matrix(.gleissberg.table)
+			
 			if (two.tailed == TRUE) { 	# two-sided probability
 				# As Gleissberg distribution is asymmetric, we have to calculate both sides independently
 				mu <- 2 / 3 * (ng - 2)
